clear

load input_data.txt      % read input data file
E_E0 = input_data(:,1)   % east coordinate (m)
N_N0 = input_data(:,2)   % nrth coordinate (m)
d_obs = input_data(:,3)  % height (m)
err = input_data(:,4)    % height error (m)
t = input_data(:,5)      % time in years since 1 1 2010
n2 = length(t)           % number of data points in input file

% show spatial distribution of data
figure()
hold
plot(E_E0,N_N0,'+')
plot(0,0,'rO')
title('distribution of test data points')
xlabel('east')
ylabel('north')

% call the function which estimate the parameters from equation 2 to 4 from
% Khan et al. (2024) in ESSD
[t2,d_est2,d_obs_corrected]=fit_poly(E_E0,N_N0,n2,t,d_obs,err);


% create mean over 0.1 y time intervals:
tt=t+2010;
kk=0;
dt=0.1;
 for tid_i=2010:dt:2024
     kk=kk+1;
 k = find(tt>tid_i & tt<=(tid_i+dt));
 t_mean(kk)=mean(tt(k));
 h_mean(kk)=mean(d_obs_corrected(k));
 h_std(kk)=std(d_obs_corrected(k));
 end

% remove nan
t_mean=(t_mean(~isnan(t_mean)));
h_mean=(h_mean(~isnan(h_mean)));
h_std=(h_std(~isnan(h_std)));
 

 figure()
 hold
 h1 = errorbar(t_mean,h_mean,h_std,'.k')
 xlabel('time [year]')
 ylabel('Elevation [m]')
 h2= plot(t2+2010, d_est2,'r.')

 legend([h1 h2],{'observed elevations','predicted elevation'})


  
