%% This Matlab scirpt covert ice volume change to ice mass change and apply 
% corrections due to vertical land motionccaused by elastic uplift and 
% glacial isostatic adjustment.
% A new nercdf file is created.

% display header of file Greenland_dhdt_icevol_1kmgrid.nc
ncdisp('Greenland_dhdt_icevol_1kmgrid.nc')

% read monthly elevation chages in eqvivalent ice. unit is m/month. 
% dhdt_vol has dimention, 1462 x 2520 x 247
Time = ncread('Greenland_dhdt_icevol_1kmgrid.nc','Time') ;
X = ncread('Greenland_dhdt_icevol_1kmgrid.nc','X') ;
Y = ncread('Greenland_dhdt_icevol_1kmgrid.nc','Y') ;
dhdt_vol = ncread('Greenland_dhdt_icevol_1kmgrid.nc','dhdt_vol') ;

% read GIA correction. note unit is mm/yr
dhdt_GIA = ncread('Greenland_GIA_1kmgrid.nc','dhdt_GIA') ;

% read firn compaction fields in m/month
dhdt_firn = ncread('Greenland_dhdt_firn_1kmgrid.nc','dhdt_firn') ;

% read vertical elastic motion ob bedrock in mm/month
dhdt_elas = ncread('Greenland_dhdt_elas_1kmgrid.nc','dhdt_elas') ;

% convert ice volume to mass. note GIA model has unit mm/yr
dhdt_mass = 0.917*dhdt_vol - dhdt_firn + 0.001*dhdt_elas + (1/12)*0.001*dhdt_GIA ;


%% write dhdt_mass to new nc file

% enter name og new file nc file:
outfile = 'Greenland_dhdt_mass_NEW_1kmgrid.nc'

% dimentions
n=length(X);
m=length(Y);
k=length(Time);

%create variable
nccreate(outfile,'X','Dimensions',{'East',n},'Datatype','single','DeflateLevel', 5);
nccreate(outfile,'Y','Dimensions',{'North',m},'Datatype','single','DeflateLevel', 5);
nccreate(outfile,'Time','Dimensions',{'Time',k},'Datatype','single','DeflateLevel', 5);
nccreate(outfile,'dhdt_mass', 'Dimensions',{'East',n,'North',m,'Time',k}, 'Datatype', 'single', 'DeflateLevel', 5)

%write data to variable
ncwrite(outfile,'X',X(1:n));
ncwrite(outfile,'Y',Y(1:m));
ncwrite(outfile,'Time',Time(1:k));
ncwrite(outfile,'dhdt_mass',dhdt_mass(1:n,1:m,1:k));

ncwriteatt(outfile, 'X', 'units', 'km');
ncwriteatt(outfile, 'Y', 'units', 'km');
ncwriteatt(outfile, 'Time', 'units', 'year');
ncwriteatt(outfile, 'dhdt_mass', 'units', 'm/month');
ncwriteatt(outfile, 'X', 'standard_name', 'East coordinate');
ncwriteatt(outfile, 'Y', 'standard_name', 'North coordinate');
ncwriteatt(outfile, 'Time', 'standard_name', 'Time in years');
ncwriteatt(outfile, 'dhdt_mass', 'standard_name', 'mean monthly elevation change rate in water equivalent');
ncwriteatt(outfile, 'dhdt_mass', 'long_name', 'mean monthly elevation change rates corrected for GIA; elastick uplift and firn compaction in water equivalent');

ncwriteatt(outfile,'/','creation_time',datestr(now));
ncwriteatt(outfile,'/','Name:','Shfaqat Abbas Khan (abbas@space.dtu.dk)');
ncwriteatt(outfile,'/','Projection type:','Polar Stereographic North (EPSG:3413)');
ncwriteatt(outfile,'/','Longitude of True Origin =','45W');
ncwriteatt(outfile,'/','Latitude of True Origin =','70N');

% display nc file variables
ncdisp(outfile);

%% create and plot time series of cummulative mass change

    dhdt_mass(isnan(dhdt_mass))=0;
    acc_mass(1)=0;
for i=2:247
    acc_mass(i)=acc_mass(i-1)+0.001*sum(sum(dhdt_mass(:,:,i)));
end
plot(Time,acc_mass)
xlabel('Time (year)')
ylabel('cummulative mass change (Gt)')
grid
